@@ -4,6 +4,7 @@
 import time
 import board
 import busio
+from rainbowio import colorwheel
 import adafruit_pca9685
 import adafruit_rgbled
 
@@ -24,24 +25,10 @@ led = adafruit_rgbled.RGBLED(RED_LED, GREEN_LED, BLUE_LED, invert_pwm=True)
 # led = adafruit_rgbled.RGBLED(RED_LED, GREEN_LED, BLUE_LED, invert_pwm=True)
 
 
-def wheel(pos):
-    # Input a value 0 to 255 to get a color value.
-    # The colours are a transition r - g - b - back to r.
-    if pos < 0 or pos > 255:
-        return 0, 0, 0
-    if pos < 85:
-        return int(255 - pos * 3), int(pos * 3), 0
-    if pos < 170:
-        pos -= 85
-        return 0, int(255 - pos * 3), int(pos * 3)
-    pos -= 170
-    return int(pos * 3), 0, int(255 - (pos * 3))
-
-
 def rainbow_cycle(wait):
     for i in range(255):
         i = (i + 1) % 256
-        led.color = wheel(i)
+        led.color = colorwheel(i)
         time.sleep(wait)
 
 
